==> ntopng-6.0.tar.gz: ntopng-6.0/include/SyslogParserInterface.h <==
/*
 *
 * (C) 2019-23 - ntop.org
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef _SYSLOG_PARSER_INTERFACE_H_
#define _SYSLOG_PARSER_INTERFACE_H_

#include "ntop_includes.h"

class SyslogParserInterface : public ParserInterface {
 private:
  SyslogLuaEngine *le;
  typedef std::map<string, string> producers_map_t;
  producers_map_t producers_map;
  bool producers_reload_requested;

 public:
  SyslogParserInterface(const char *endpoint,
                        const char *custom_interface_type = NULL);
  ~SyslogParserInterface();

  void addProducerMapping(const char *host, const char *producer);
  void doProducersMappingUpdate();
  void updateProducersMapping() { producers_reload_requested = true; };
  const char *getProducerName(const char *host);

  u_int8_t parseLog(char *log_line, char *client_ip);

  u_int32_t getNumDroppedPackets() { return 0; };
  virtual void lua(lua_State *vm);
  virtual void startPacketPolling();
};

#endif /* _SYSLOG_PARSER_INTERFACE_H_ */

==> ntopng-6.2.tar.gz: ntopng-6.2/include/SyslogParserInterface.h <==
/*
 *
 * (C) 2019-24 - ntop.org
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef _SYSLOG_PARSER_INTERFACE_H_
#define _SYSLOG_PARSER_INTERFACE_H_

#include "ntop_includes.h"

class SyslogParserInterface : public ParserInterface {
 private:
  SyslogLuaEngine *le;
  typedef std::map<string, string> producers_map_t;
  producers_map_t producers_map;
  bool producers_reload_requested;

 public:
  SyslogParserInterface(const char *endpoint,
                        const char *custom_interface_type = NULL);
  ~SyslogParserInterface();

  void addProducerMapping(const char *host, const char *producer);
  void doProducersMappingUpdate();
  void updateProducersMapping() { producers_reload_requested = true; };
  const char *getProducerName(const char *host);

  u_int8_t parseLog(char *log_line, char *client_ip);

  u_int32_t getNumDroppedPackets() { return 0; };
  virtual void lua(lua_State *vm, bool fullStats);
  virtual void startPacketPolling();
};

#endif /* _SYSLOG_PARSER_INTERFACE_H_ */
